==> pnetlib-0.5.8.tar.gz: pnetlib-0.5.8/System.Xml/Schema/XmlSchemaObjectCollection.cs <==
/*
 * XmlSchemaObjectCollection.cs - Implementation of 
 *					"XmlSchemaObjectCollection" class
 *
 * Copyright (C) 2003  Southern Storm Software, Pty Ltd.
 * 
 * contributed by Gopal.V 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

using System;
using System.Collections;

namespace System.Xml.Schema
{
	public class XmlSchemaObjectCollection:CollectionBase
	{
		[TODO]
		public XmlSchemaObjectCollection()
		{
			 throw new NotImplementedException(".ctor");
		}

		[TODO]
		public XmlSchemaObjectCollection(XmlSchemaObject parent)
		{
			 throw new NotImplementedException(".ctor");
		}

		[TODO]
		public int Add(XmlSchemaObject item)
		{
			 throw new NotImplementedException("Add");
		}

		[TODO]
		public bool Contains(XmlSchemaObject item)
		{
			 throw new NotImplementedException("Contains");
		}

		[TODO]
		public void CopyTo(XmlSchemaObject[] array, int index)
		{
			 throw new NotImplementedException("CopyTo");
		}

		[TODO]
		public override XmlSchemaObjectEnumerator GetEnumerator()
		{
			 throw new NotImplementedException("GetEnumerator");
		}

		[TODO]
		public int IndexOf(XmlSchemaObject item)
		{
			 throw new NotImplementedException("IndexOf");
		}

		[TODO]
		public void Insert(int index, XmlSchemaObject item)
		{
			 throw new NotImplementedException("Insert");
		}

		[TODO]
		protected override void OnClear()
		{
			 throw new NotImplementedException("OnClear");
		}

		[TODO]
		protected override void OnInsert(int index, Object item)
		{
			 throw new NotImplementedException("OnInsert");
		}

		[TODO]
		protected override void OnRemove(int index, Object item)
		{
			 throw new NotImplementedException("OnRemove");
		}

		[TODO]
		protected override void OnSet(int index, Object oldValue, Object newValue)
		{
			 throw new NotImplementedException("OnSet");
		}

		[TODO]
		public void Remove(XmlSchemaObject item)
		{
			 throw new NotImplementedException("Remove");
		}

		[TODO]
		public virtual XmlSchemaObject this[int index] 
		{
 			get
			{
				throw new NotImplementedException("Item");
			}
 			set
			{
				throw new NotImplementedException("Item");
			}
 		}

	}
}//namespace

==> pnetlib-0.5.12.tar.gz: pnetlib-0.5.12/System.Xml/Schema/XmlSchemaObjectCollection.cs <==
/*
 * XmlSchemaObjectCollection.cs - Implementation of 
 *					"XmlSchemaObjectCollection" class
 *
 * Copyright (C) 2003  Southern Storm Software, Pty Ltd.
 * 
 * contributed by Gopal.V 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

using System;
using System.Collections;

namespace System.Xml.Schema
{
	public class XmlSchemaObjectCollection:CollectionBase
	{
		[TODO]
		public XmlSchemaObjectCollection()
		{
			 throw new NotImplementedException(".ctor");
		}

		[TODO]
		public XmlSchemaObjectCollection(XmlSchemaObject parent)
		{
			 throw new NotImplementedException(".ctor");
		}

		[TODO]
		public int Add(XmlSchemaObject item)
		{
			 throw new NotImplementedException("Add");
		}

		[TODO]
		public bool Contains(XmlSchemaObject item)
		{
			 throw new NotImplementedException("Contains");
		}

		[TODO]
		public void CopyTo(XmlSchemaObject[] array, int index)
		{
			 throw new NotImplementedException("CopyTo");
		}

		[TODO]
		public new XmlSchemaObjectEnumerator GetEnumerator()
		{
			 throw new NotImplementedException("GetEnumerator");
		}

		[TODO]
		public int IndexOf(XmlSchemaObject item)
		{
			 throw new NotImplementedException("IndexOf");
		}

		[TODO]
		public void Insert(int index, XmlSchemaObject item)
		{
			 throw new NotImplementedException("Insert");
		}

		[TODO]
		protected override void OnClear()
		{
			 throw new NotImplementedException("OnClear");
		}

		[TODO]
		protected override void OnInsert(int index, Object item)
		{
			 throw new NotImplementedException("OnInsert");
		}

		[TODO]
		protected override void OnRemove(int index, Object item)
		{
			 throw new NotImplementedException("OnRemove");
		}

		[TODO]
		protected override void OnSet(int index, Object oldValue, Object newValue)
		{
			 throw new NotImplementedException("OnSet");
		}

		[TODO]
		public void Remove(XmlSchemaObject item)
		{
			 throw new NotImplementedException("Remove");
		}

		[TODO]
		public virtual XmlSchemaObject this[int index] 
		{
 			get
			{
				throw new NotImplementedException("Item");
			}
 			set
			{
				throw new NotImplementedException("Item");
			}
 		}

	}
}//namespace
